arrc.callbacks.tsne\_visualizer\_callback
=========================================

.. automodule:: arrc.callbacks.tsne_visualizer_callback

   
   .. rubric:: Classes

   .. autosummary::
   
      EmbeddingVisualizerCallback
   